@@ -116,7 +116,8 @@ class Converters:
                 for tag in catalog["tags"]
             ]
             if catalog["tags"]
-            else []
+            else [],
+            policy=Converters.create_blueprint_policy_response(catalog["policies"]),
         )
 
     @staticmethod
@@ -146,7 +147,8 @@ class Converters:
                 for tag in catalog["tags"]
             ]
             if catalog["tags"]
-            else []
+            else [],
+            policy=Converters.create_blueprint_policy_response(catalog["policies"]),
         )
 
     @staticmethod
@@ -237,7 +239,8 @@ class Converters:
                 for tag in blueprint["tags"]
             ]
             if blueprint["tags"]
-            else []
+            else [],
+            policy=Converters.create_blueprint_policy_response(blueprint["policies"]),
         )
 
     @staticmethod
@@ -1395,7 +1398,9 @@ class Converters:
         )
 
     @staticmethod
-    def create_blueprint_policy_response(data: dict) -> BlueprintPolicyResponse:
+    def create_blueprint_policy_response(data: dict) -> Optional[BlueprintPolicyResponse]:
+        if data is None:
+            return None
         return BlueprintPolicyResponse(
             max_duration=isodate.parse_duration(data['max_duration']) if data['max_duration'] else None
         )
