@@ -112,6 +112,11 @@ class CatalogApplicationResponse:
         self.version = version
 
 
+class BlueprintPolicyResponse:
+    def __init__(self, max_duration: timedelta):
+        self.max_duration = max_duration
+
+
 class CatalogForGetResponse:
     def __init__(
             self,
@@ -126,6 +131,7 @@ class CatalogForGetResponse:
             artifacts: Dict[str, str],
             errors: [],
             tags: List[BlueprintTagResponse],
+            policy: BlueprintPolicyResponse
     ):
         self.errors = errors
         self.links = links
@@ -138,6 +144,7 @@ class CatalogForGetResponse:
         self.applications = applications
         self.artifacts = artifacts
         self.tags = tags
+        self.policy = policy
 
 
 class CatalogForGetAllResponse:
@@ -153,6 +160,7 @@ class CatalogForGetAllResponse:
             artifacts: Dict[str, str],
             errors: [],
             tags: List[BlueprintTagResponse],
+            policy: BlueprintPolicyResponse
     ):
         self.links = links
         self.url = url
@@ -164,6 +172,7 @@ class CatalogForGetAllResponse:
         self.artifacts = artifacts
         self.errors = errors
         self.tags = tags
+        self.policy = policy
 
 
 class BlueprintApplicationResponse:
@@ -256,7 +265,8 @@ class BlueprintResponse:
             is_sample,
             services: List[BlueprintServiceResponse],
             environment_type: str,
-            tags: List[BlueprintTagResponse]
+            tags: List[BlueprintTagResponse],
+            policy: BlueprintPolicyResponse
     ):
         self.errors = errors
         self.is_sample = is_sample
@@ -274,6 +284,7 @@ class BlueprintResponse:
         self.services = services
         self.environment_type = environment_type
         self.tags = tags
+        self.policy = policy
 
 
 class SourceControlDetailsResponse:
@@ -1367,9 +1378,6 @@ class CreateAccountFinalizeResponse:
         self.last_name = last_name
 
 
-
-
-
 class CustomTagOverrideResponse:
     def __init__(self,
                  name: str,
@@ -1433,11 +1441,6 @@ class SpaceTerraformModuleResponse:
         self.inputs = inputs
 
 
-class BlueprintPolicyResponse:
-    def __init__(self, max_duration: timedelta):
-        self.max_duration = max_duration
-        
-
 class SpaceHelmChartResponse:
     def __init__(
             self,
